OC.L10N.register(
    "files_trashbin",
    {
    "Couldn't delete %s permanently" : "Nevarēja pilnībā izdzēst %s",
    "Couldn't restore %s" : "Nevarēja atjaunot %s",
    "Deleted files" : "Dzēstās datnes",
    "Restore" : "Atjaunot",
    "Delete" : "Dzēst",
    "Delete permanently" : "Dzēst pavisam",
    "Error" : "Kļūda",
    "This operation is forbidden" : "Šī darbība ir aizliegta",
    "This directory is unavailable, please check the logs or contact the administrator" : "Šis direktorijs nav pieejams, lūdzu pārbaudiet žurnālus vai sazinieties ar administratoru",
    "restored" : "atjaunots",
    "No deleted files" : "Nav dzēstu failu",
    "You will be able to recover deleted files from here" : "No šejienes būs iespējams atgūt dzēstos failus",
    "No entries found in this folder" : "Šajā mapē nekas nav atrasts",
    "Select all" : "Atzīmēt visu",
    "Name" : "Nosaukums",
    "Deleted" : "Dzēsts"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
